trace_discovery_handler

Function trace_discovery_handler 

pub fn trace_discovery_handler(
    discovery_results: Vec<DiscoveryReply>,
    catcher_id: u32,
    worker_stacks: &mut HashMap<u32, VecDeque<Task>>,
    traceroute_config: &mut TracerouteConfig,
    origin_id: u32,
)
Handles discovery replies for traceroute measurements. Initializes a TraceSession for a traceroute from the catching worker to the target. Also instruct the catching Worker to send a Trace with TTL = 1.

Arguments

  • discovery_results - List of discovery results
  • worker_id - Worker that received the discovery results and will perform the traceroute
  • worker_stacks - Shared stack to put follow-up tasks into
  • traceroute_config - Traceroute parameters
  • origin_id - Origin for which these replies are received