pub fn trace_discovery_handler(
discovery_results: Vec<DiscoveryReply>,
catcher_id: u32,
worker_stacks: &mut HashMap<u32, VecDeque<Task>>,
traceroute_config: &mut TracerouteConfig,
origin_id: u32,
)Expand description
Handles discovery replies for traceroute measurements.
Initializes a TraceSession for a traceroute from the catching worker to the target.
Also instruct the catching Worker to send a Trace with TTL = 1.
Arguments
discovery_results- List of discovery resultsworker_id- Worker that received the discovery results and will perform the tracerouteworker_stacks- Shared stack to put follow-up tasks intotraceroute_config- Traceroute parametersorigin_id- Origin for which these replies are received